#define TWOCHANNELS TWOCHANNELSPLACEHOLDER

varying highp vec2 textureCoordinate0;
varying highp vec2 textureCoordinate1;
varying highp vec2 textureCoordinate2;
varying highp vec2 textureCoordinate3;
varying highp vec2 textureCoordinate4;
varying highp vec2 textureCoordinate5;
varying highp vec2 textureCoordinate6;
varying highp vec2 textureCoordinate7;

uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture2;

uniform int kernelSize;

uniform highp vec4 kernel0;
uniform highp vec4 kernel1;

#if TWOCHANNELS == 1
highp vec2 readColor(highp vec2 coords)
{
    highp vec4 textureColor = texture2D(inputImageTexture, coords);
    highp float channel1 = textureColor.x * 255. + textureColor.y;
    highp float channel2 = textureColor.z * 255. + textureColor.w;
    return vec2(channel1, channel2);
}
#else
highp float readColor(highp vec2 coords)
{
    highp vec4 textureColor = texture2D(inputImageTexture, coords);
    return textureColor.x * 255. + textureColor.y;
}
#endif

void main()
{
    #if TWOCHANNELS == 1
    highp vec2 textureColor;
    highp vec2 outputColor;
    #else
    highp float textureColor;
    highp float outputColor;
    #endif
    
    textureColor = readColor(textureCoordinate0);
    outputColor = kernel0.x * textureColor;
    textureColor = readColor(textureCoordinate1);
    outputColor += kernel0.y * textureColor;
    textureColor = readColor(textureCoordinate2);
    outputColor += kernel0.z * textureColor;
    textureColor = readColor(textureCoordinate3);
    outputColor += kernel0.w * textureColor;
    
    textureColor = readColor(textureCoordinate4);
    outputColor += kernel1.x * textureColor;
    textureColor = readColor(textureCoordinate5);
    outputColor += kernel1.y * textureColor;
    textureColor = readColor(textureCoordinate6);
    outputColor += kernel1.z * textureColor;
    
    outputColor = max(abs(outputColor), .00002);
    
    //highp vec4 accColor = texture2D(inputImageTexture2, gl_FragCoord.xy);
    highp vec4 accColor = texture2D(inputImageTexture2, textureCoordinate7);
    //highp vec4 outputColor = vec4(0.);
    //highp vec4 accColor = vec4(0.);
    #if TWOCHANNELS == 1
    outputColor.x = outputColor.x + accColor.x * 255. + accColor.y;
    outputColor.y = outputColor.y + accColor.z * 255. + accColor.w;
    gl_FragColor.x = floor(outputColor.x) / 255.;
    gl_FragColor.y = fract(outputColor.x);
    gl_FragColor.z = floor(outputColor.y) / 255.;
    gl_FragColor.w = fract(outputColor.y);
    #else
    outputColor = outputColor + accColor.x * 255. + accColor.y;
    gl_FragColor.x = floor(outputColor) / 255.;
    gl_FragColor.y = fract(outputColor);
    #endif
}
